/*
*/


#include "device.h"

#ifdef ALLOC_PRAGMA
#pragma code_seg("PAGE")
#endif // ALLOC_PRAGMA


/* Private variables */

/**
 * This is the dispatch table for the device. Plug and play
 * notifications as well as power management notifications are dispatched
 * through this table.
 */
static const
KSDEVICE_DISPATCH
deviceDispatch = {
    Device::DispatchPnpAdd,    // Pnp Add Device
    Device::DispatchPnpStart,  // Pnp Start
    NULL,                      // Post-Start
    NULL,                      // Pnp Query Stop
    NULL,                      // Pnp Cancel Stop
    Device::DispatchPnpStop,   // PnP Stop
    NULL,                      // Pnp Query Remove
    NULL,                      // Pnp Cancel Remove
    NULL, /*Device::DispatchPnpRemove,*/ // Pnp Remove
    NULL,                      // Pnp Query Capabilities
    NULL,                      // Pnp Surprise Removal
    NULL,                      // Power Query Power
    NULL, /*Device::DispatchSetPower,*/ // Power Set Power
    NULL                       // Pnp Query Interface
};

/**
 * This is the device descriptor for the complete device. It points to the
 * dispatch table. No filter descriptors are statically in this descriptor.
 * This driver uses KsCreateFilterFactory to create the filters.
 */
static const
KSDEVICE_DESCRIPTOR
deviceDescriptor = {
    &deviceDispatch,
    0,
    NULL,  // the filter descriptor is NULL, use KsCreateFilterFactory to create it dynamically
    KSDEVICE_DESCRIPTOR_VERSION
};


// true if driver is running on Vista
// false if Win XP
//bool gIsVista = false;

// unload routine provided by KS
//PDRIVER_UNLOAD gKsUnloadRoutine = NULL;


/* Private functions */

/**
 *
 */
/*
static
void
DriverUnload(DRIVER_OBJECT *ksDriverObject)
{
    DPF_ENTER(("[DriverUnload]"));
    // call KS unload routine
    //if ( gKsUnloadRoutine != NULL ) {
    //    gKsUnloadRoutine(driver_object);
    //}
}
*/



///////////

extern "C" DRIVER_INITIALIZE DriverEntry;
extern "C"
NTSTATUS
DriverEntry(DRIVER_OBJECT *ksDriverObject, UNICODE_STRING *registryPath)
{
    DbgPrint("DriverEntry\n");

    NTSTATUS status = ::KsInitializeDriver(ksDriverObject, registryPath, &deviceDescriptor);

    if (NT_SUCCESS(status)) {
        // install our unload hook
        //gKsUnloadRoutine = driver_object->DriverUnload;
        //driver_object->DriverUnload = DriverUnload;
    }

    return status;
}







